@@ -32,14 +32,14 @@ from gamutrf.sigwindows import scipy_find_sig_windows
 from gamutrf.utils import rotate_file_n, SCAN_FRES
 
 MB = int(1.024e6)
-FFT_BUFFER_TIME = 3
+FFT_BUFFER_TIME = 1
 BUFF_FILE = "/dev/shm/scanfftbuffer.txt.zst"  # nosec
 PEAK_TRIGGER = int(os.environ.get("PEAK_TRIGGER", "0"))
 PIN_TRIGGER = int(os.environ.get("PIN_TRIGGER", "17"))
 if PEAK_TRIGGER == 1:
     import RPi.GPIO as GPIO
 
-    GPIO.setmode(GPIO.BOARD)
+    GPIO.setmode(GPIO.BCM)
     GPIO.setup(PIN_TRIGGER, GPIO.OUT)
 
 PEAK_DBS = {}
